@@ -14,12 +14,14 @@
  * SOFTWARE.
  */
 
-pub extern crate dmntk_examples;
-pub extern crate dmntk_feel_parser;
+extern crate dmntk_common;
+extern crate dmntk_examples;
+extern crate dmntk_feel;
+extern crate dmntk_feel_parser;
 extern crate roxmltree;
 
 use crate::model::Definitions;
-use dmntk_feel_parser::dmntk_feel::dmntk_common::Result;
+use dmntk_common::Result;
 
 pub mod model;
 
