@@ -23,8 +23,8 @@ pub(crate) mod parser;
 mod tests;
 
 use self::errors::*;
-use dmntk_feel_parser::dmntk_feel::dmntk_common::{DmntkError, HRef, OptHRef, Result};
-use dmntk_feel_parser::dmntk_feel::{FeelType, Name};
+use dmntk_common::{DmntkError, HRef, OptHRef, Result};
+use dmntk_feel::{FeelType, Name};
 use std::convert::TryFrom;
 
 /// [Element] represents an element from another metamodel.
@@ -408,13 +408,28 @@ impl Definitions {
   pub fn item_definition_by_name(&self, name: &str) -> Option<&ItemDefinition> {
     self.item_definitions.iter().find(|v| v.name() == name)
   }
+  /// Returns a vector of references to decisions.
+  pub fn decisions(&self) -> Vec<&Decision> {
+    self
+      .drg_elements
+      .iter()
+      .filter_map(|drg_element| {
+        if drg_element.is_decision() {
+          if let DrgElement::Decision(inner) = drg_element {
+            return Some(inner);
+          }
+        }
+        None
+      })
+      .collect()
+  }
   /// Returns an optional reference to [Decision] with specified identifier
   /// or [None] when such [Decision] was not found among instances of [DrgElement].
   pub fn decision_by_id(&self, id: &str) -> Option<&Decision> {
     self.drg_elements.iter().find_map(|v| {
       if v.is_decision() && v.has_id(id) {
-        if let DrgElement::Decision(decision) = v {
-          return Some(decision);
+        if let DrgElement::Decision(inner) = v {
+          return Some(inner);
         }
       }
       None
@@ -425,13 +440,28 @@ impl Definitions {
   pub fn decision_by_name(&self, name: &str) -> Option<&Decision> {
     self.drg_elements.iter().find_map(|v| {
       if v.is_decision() && v.has_name(name) {
-        if let DrgElement::Decision(decision) = v {
-          return Some(decision);
+        if let DrgElement::Decision(inner) = v {
+          return Some(inner);
         }
       }
       None
     })
   }
+  /// Returns a vector of references to business knowledge models.
+  pub fn business_knowledge_models(&self) -> Vec<&BusinessKnowledgeModel> {
+    self
+      .drg_elements
+      .iter()
+      .filter_map(|drg_element| {
+        if drg_element.is_business_knowledge_model() {
+          if let DrgElement::BusinessKnowledgeModel(inner) = drg_element {
+            return Some(inner);
+          }
+        }
+        None
+      })
+      .collect()
+  }
   /// Returns an optional reference to [BusinessKnowledgeModel] with specified identifier
   /// or [None] when such [BusinessKnowledgeModel] was not found among instances of [DrgElement].
   pub fn business_knowledge_model_by_id(&self, id: &str) -> Option<&BusinessKnowledgeModel> {
@@ -486,8 +516,8 @@ impl Definitions {
   pub fn input_data_by_id(&self, id: &str) -> Option<&InputData> {
     self.drg_elements.iter().find_map(|v| {
       if v.is_input_data() && v.has_id(id) {
-        if let DrgElement::InputData(input_data) = v {
-          return Some(input_data);
+        if let DrgElement::InputData(inner) = v {
+          return Some(inner);
         }
       }
       None
@@ -506,8 +536,8 @@ impl Definitions {
   pub fn knowledge_source_by_id(&self, id: &str) -> Option<&KnowledgeSource> {
     self.drg_elements.iter().find_map(|v| {
       if v.is_knowledge_source() && v.has_id(id) {
-        if let DrgElement::KnowledgeSource(input_data) = v {
-          return Some(input_data);
+        if let DrgElement::KnowledgeSource(inner) = v {
+          return Some(inner);
         }
       }
       None
@@ -517,6 +547,10 @@ impl Definitions {
   pub fn business_context_elements(&self) -> &Vec<BusinessContextElementInstance> {
     &self.business_context_elements
   }
+  /// Returns reference to source model.
+  pub fn source(&self) -> &String {
+    &self.source
+  }
   /// Returns reference to optional [Dmndi] container.
   pub fn dmndi(&self) -> &Option<Dmndi> {
     &self.dmndi
@@ -750,9 +784,9 @@ impl Context {
 pub struct ContextEntry {
   /// The instance of [InformationItem] that is contained in this [ContextEntry],
   /// and whose name is the key in the modeled context entry.
-  variable: Option<InformationItem>,
+  pub variable: Option<InformationItem>,
   /// The instance of [Expression] that is the expression in this [ContextEntry].
-  value: ExpressionInstance,
+  pub value: ExpressionInstance,
 }
 
 /// [LiteralExpression] is used to model a value expression whose value
@@ -908,6 +942,14 @@ pub struct Decision {
 }
 
 impl Decision {
+  /// Returns a reference to a natural language question that characterizes the [Decision].
+  pub fn question(&self) -> &Option<String> {
+    &self.question
+  }
+  /// Returns a reference to a natural language description of the answers allowed for the question defined in this [Decision].
+  pub fn allowed_answers(&self) -> &Option<String> {
+    &self.allowed_answers
+  }
   /// Return a reference to a variable that stores the result of this [Decision].
   pub fn variable(&self) -> &InformationItem {
     &self.variable
@@ -1194,7 +1236,7 @@ pub trait Invocable: DmnElement + NamedElement {
 /// Instances of `Invocable` interface.
 #[derive(Debug, Clone)]
 pub enum InvocableInstance {
-  BusinessKnowledgeModel(BusinessKnowledgeModel),
+  BusinessKnowledgeModel(Box<BusinessKnowledgeModel>),
   DecisionService, // TODO add DecisionService
 }
 
@@ -1374,7 +1416,7 @@ impl Invocable for DecisionService {
 }
 
 /// Item definition types.
-#[derive(Debug, Clone)]
+#[derive(Debug, Clone, PartialEq)]
 pub enum ItemDefinitionType {
   SimpleType(FeelType),
   ReferencedType(String),
@@ -1456,6 +1498,10 @@ impl ItemDefinition {
   pub fn set_feel_type(&mut self, feel_type: FeelType) {
     self.feel_type = Some(feel_type);
   }
+  /// Returns a reference to an optional [FunctionItem] that compose this [ItemDefinition].
+  pub fn function_item(&self) -> &Option<FunctionItem> {
+    &self.function_item
+  }
   /// Returns a reference to optional item definition type.
   pub fn item_definition_type(&self) -> &Option<ItemDefinitionType> {
     &self.item_definition_type
@@ -2234,7 +2280,7 @@ pub enum DcKnownColor {
 }
 
 mod errors {
-  use dmntk_feel_parser::dmntk_feel::dmntk_common::DmntkError;
+  use dmntk_common::DmntkError;
 
   /// Errors related to the model.
   #[derive(Debug, PartialEq)]
