@@ -19,7 +19,7 @@
 use self::errors::*;
 use self::xml_utils::*;
 use super::*;
-use dmntk_feel_parser::dmntk_feel::dmntk_common::Result;
+use dmntk_common::Result;
 use roxmltree::Node;
 
 const NODE_ALLOWED_ANSWERS: &str = "allowedAnswers";
@@ -126,7 +126,7 @@ pub struct ModelParser {}
 impl ModelParser {
   /// Parses the XML document containing definitions.
   pub fn parse(&mut self, xml: &str, source: &str) -> Result<Definitions> {
-    match roxmltree::Document::parse(&xml) {
+    match roxmltree::Document::parse(xml) {
       Ok(document) => {
         let definitions_node = document.root_element();
         if definitions_node.tag_name().name() != NODE_DEFINITIONS {
@@ -420,7 +420,7 @@ impl ModelParser {
       label: optional_attribute(node, ATTR_LABEL),
       extension_elements: self.parse_extension_elements(node),
       extension_attributes: self.parse_extension_attributes(node),
-      name: required_name(&node)?,
+      name: required_name(node)?,
       feel_name: optional_feel_name(node)?,
       value_expression: self.parse_optional_expression_instance(node)?,
       type_ref: optional_attribute(node, ATTR_TYPE_REF),
@@ -439,7 +439,7 @@ impl ModelParser {
   fn parse_information_requirement(&self, node: &Node) -> Result<InformationRequirement> {
     Ok(InformationRequirement {
       id: optional_attribute(node, ATTR_ID),
-      description: optional_child_optional_content(&node, NODE_DESCRIPTION),
+      description: optional_child_optional_content(node, NODE_DESCRIPTION),
       label: optional_attribute(node, ATTR_LABEL),
       extension_elements: self.parse_extension_elements(node),
       extension_attributes: self.parse_extension_attributes(node),
@@ -459,7 +459,7 @@ impl ModelParser {
   fn parse_knowledge_requirement(&self, node: &Node) -> Result<KnowledgeRequirement> {
     Ok(KnowledgeRequirement {
       id: optional_attribute(node, ATTR_ID),
-      description: optional_child_optional_content(&node, NODE_DESCRIPTION),
+      description: optional_child_optional_content(node, NODE_DESCRIPTION),
       label: optional_attribute(node, ATTR_LABEL),
       extension_elements: self.parse_extension_elements(node),
       extension_attributes: self.parse_extension_attributes(node),
@@ -622,7 +622,7 @@ impl ModelParser {
     let mut context_entries = vec![];
     for ref child_node in node.children().filter(|n| n.tag_name().name() == NODE_CONTEXT_ENTRY) {
       context_entries.push(ContextEntry {
-        variable: self.parse_optional_information_item_child(&child_node, NODE_VARIABLE)?,
+        variable: self.parse_optional_information_item_child(child_node, NODE_VARIABLE)?,
         value: self.parse_required_expression_instance(child_node)?,
       });
     }
@@ -998,13 +998,11 @@ impl ModelParser {
 
 /// Utility helper functions for processing XML structures.
 mod xml_utils {
-  use std::str::FromStr;
-
-  use dmntk_feel_parser::dmntk_feel::dmntk_common::{OptHRef, Result};
-  use roxmltree::Node;
-
   use super::errors::*;
   use super::*;
+  use dmntk_common::{OptHRef, Result};
+  use roxmltree::Node;
+  use std::str::FromStr;
 
   /// Returns the value of the required attribute.
   pub fn required_attribute(node: &Node, attr_name: &str) -> Result<String> {
@@ -1127,7 +1125,7 @@ mod xml_utils {
 
 /// Definitions of errors raised while parsing the XML model.
 mod errors {
-  use dmntk_feel_parser::dmntk_feel::dmntk_common::DmntkError;
+  use dmntk_common::DmntkError;
 
   /// Errors related with parsing the decision model.
   enum ModelParserError {
