@@ -15,17 +15,18 @@
  */
 
 use crate::model::*;
-use dmntk_feel_parser::dmntk_feel::dmntk_common::Stringify;
+
+const NAMESPACE: &str = "https://dmntk.io";
 
 #[test]
-fn test_2_0001() {
+fn _2_0001() {
   // <definitions>
   let definitions = crate::parse(dmntk_examples::DMN_2_0001, "file://2_0001.dmn").unwrap();
   assert_eq!("_c910c9ba-c584-4ac9-a773-1e6de185cd85", definitions.id().as_ref().unwrap().as_str());
-  assert!(definitions.description().is_none());
+  assert_eq!("Compliance level 2. Test 0001.", definitions.description().as_ref().unwrap().as_str());
   assert!(definitions.label().is_none());
-  assert_eq!("compliance-level-2-test-0001-input-data-string", definitions.name());
-  assert_eq!("https://dmntk.io", definitions.namespace());
+  assert_eq!("compliance-level-2-test-0001", definitions.name());
+  assert_eq!(NAMESPACE, definitions.namespace());
   assert!(definitions.expression_language().is_none());
   assert!(definitions.type_language().is_none());
   assert!(definitions.exporter().is_none());
@@ -79,21 +80,22 @@ fn test_2_0001() {
 }
 
 #[test]
-fn test_2_0002() {
+fn _2_0002() {
   // <definitions>
   let definitions = crate::parse(dmntk_examples::DMN_2_0002, "file://2_0002.dmn").unwrap();
   assert_eq!("_072005e3-2635-47c9-8dec-5aca4b869376", definitions.id().as_ref().unwrap().as_str());
+  assert_eq!(NAMESPACE, definitions.namespace());
 }
 
 #[test]
-fn test_2_0003() {
+fn _2_0003() {
   // <definitions>
   let definitions = crate::parse(dmntk_examples::DMN_2_0003, "file://2_0003.dmn").unwrap();
-  assert_eq!("_0003-input-data-string-allowed-values", definitions.id().as_ref().unwrap().as_str());
-  assert!(definitions.description().is_none());
+  assert_eq!("_ce8a8d19-38c0-4289-8a46-ff72f881e71f", definitions.id().as_ref().unwrap().as_str());
+  assert_eq!("Compliance level 2. Test 0003.", definitions.description().as_ref().unwrap().as_str());
   assert!(definitions.label().is_none());
-  assert_eq!("0003-input-data-string-allowed-values", definitions.name());
-  assert_eq!("https://github.com/agilepro/dmn-tck", definitions.namespace());
+  assert_eq!("compliance-level-2-test-0003", definitions.name());
+  assert_eq!(NAMESPACE, definitions.namespace());
   assert_eq!(2, definitions.drg_elements.len());
   // <definitions>.<itemDefinition>
   let item_definition = definitions.item_definition_by_name("tEmploymentStatus").unwrap();
@@ -159,14 +161,14 @@ fn test_2_0003() {
 }
 
 #[test]
-fn test_2_0004() {
+fn _2_0004() {
   // checking node: <definitions>
   let definitions = crate::parse(dmntk_examples::DMN_2_0004, "file://2_0004.dmn").unwrap();
   assert_eq!("_edbd2d8e-a5a8-4660-9bb9-adaa792d900c", definitions.id().as_ref().unwrap().as_str());
   assert!(definitions.description().is_none());
   assert!(definitions.label().is_none());
-  assert_eq!("simple U table", definitions.name());
-  assert_eq!("https://github.com/dmn-tck/tck", definitions.namespace());
+  assert_eq!("compliance-level-2-test-0004", definitions.name());
+  assert_eq!("https://dmntk.io", definitions.namespace());
   assert_eq!(4, definitions.drg_elements.len());
   // checking node: <definitions>.<decision>
   let decision = definitions.decision_by_id("_3b2953a3-745f-4d2e-b55d-75c8c5ae653c").unwrap();
@@ -195,34 +197,34 @@ fn test_2_0004() {
 }
 
 #[test]
-fn test_2_0005() {
+fn _2_0005() {
   // <definitions>
   let definitions = crate::parse(dmntk_examples::DMN_2_0005, "file://2_0005.dmn").unwrap();
   assert_eq!("_6cb03678-38e5-4ee3-826b-d6622c738563", definitions.id().as_ref().unwrap().as_str());
 }
 
 #[test]
-fn test_2_0006() {
+fn _2_0006() {
   // <definitions>
   let definitions = crate::parse(dmntk_examples::DMN_2_0006, "file://2_0006.dmn").unwrap();
   assert_eq!("_ecea0c06-d5d0-41c2-9ba9-a9153fb47e7b", definitions.id().as_ref().unwrap().as_str());
 }
 
 #[test]
-fn test_2_0008() {
+fn _2_0008() {
   // <definitions>
   let definitions = crate::parse(dmntk_examples::DMN_2_0008, "file://2_0008.dmn").unwrap();
-  assert_eq!("_1fedf2c0-0f4a-470c-bc66-a15528e8a49a", definitions.id().as_ref().unwrap().as_str());
+  assert_eq!("_e2d61fd1-c220-4359-9f7e-b42474c7983f", definitions.id().as_ref().unwrap().as_str());
 }
 
 #[test]
-fn test_2_0009() {
+fn _2_0009() {
   let definitions = crate::parse(dmntk_examples::DMN_2_0009, "file://2_0009.dmn").unwrap();
-  assert_eq!("_4c08a169-c69a-4be7-93a6-0dcb8286b24d", definitions.id().as_ref().unwrap().as_str());
+  assert_eq!("_0ffc2622-d6db-4650-aac3-46df54e9d5c2", definitions.id().as_ref().unwrap().as_str());
   assert!(definitions.description().is_none());
   assert!(definitions.label().is_none());
-  assert_eq!("0009-invocation-arithmetic", definitions.name());
-  assert_eq!("https://github.com/dmn-tck/tck", definitions.namespace());
+  assert_eq!("compliance-level-2-test-0009", definitions.name());
+  assert_eq!("https://dmntk.io", definitions.namespace());
   assert_eq!(4, definitions.drg_elements.len());
   // <definitions>.<decision>
   let decision = definitions.decision_by_id("d_MonthlyPayment").unwrap();
@@ -279,28 +281,28 @@ fn test_2_0009() {
 }
 
 #[test]
-fn test_2_0010() {
+fn _2_0010() {
   // <definitions>
   let definitions = crate::parse(dmntk_examples::DMN_2_0010, "file://2_0010.dmn").unwrap();
   assert_eq!("_00559901-ef96-4bd2-9301-58204de7a888", definitions.id().as_ref().unwrap().as_str());
 }
 
 #[test]
-fn test_2_0106() {
+fn _2_0106() {
   // <definitions>
   let definitions = crate::parse(dmntk_examples::DMN_2_0106, "file://2_0106.dmn").unwrap();
   assert_eq!("_09efab6a-892b-452f-9182-492a89540a20", definitions.id().as_ref().unwrap().as_str());
 }
 
 #[test]
-fn test_3_0001() {
+fn _3_0001() {
   // <definitions>
   let definitions = crate::parse(dmntk_examples::DMN_3_0001, "file://3_0001.dmn").unwrap();
   assert_eq!("_180a340c-6910-41a7-ab7e-8739f70fb91a", definitions.id().as_ref().unwrap().as_str());
 }
 
 #[test]
-fn test_parse_context_3_0002() {
+fn _3_0002() {
   let definitions = crate::parse(dmntk_examples::DMN_3_0002, "file:///3_0002.dmn").unwrap();
   assert_eq!("_c2dc9bd5-010e-4351-b375-7db74d8ba69d", definitions.id().as_ref().unwrap().as_str());
   // <definitions>.<decision>
@@ -326,42 +328,49 @@ fn test_parse_context_3_0002() {
 }
 
 #[test]
-fn test_3_0003() {
+fn _3_0003() {
   // <definitions>
   let definitions = crate::parse(dmntk_examples::DMN_3_0003, "file://3_0003.dmn").unwrap();
   assert_eq!("_54863c52-2fa7-4a3d-b383-d4eb2eb88771", definitions.id().as_ref().unwrap().as_str());
 }
 
 #[test]
-fn test_3_0004() {
+fn _3_0004() {
   // <definitions>
   let definitions = crate::parse(dmntk_examples::DMN_3_0004, "file://3_0004.dmn").unwrap();
   assert_eq!("_a0f3517d-ee37-4724-8beb-81d28b145e17", definitions.id().as_ref().unwrap().as_str());
 }
 
 #[test]
-fn test_3_0006() {
+fn _3_0006() {
   // <definitions>
   let definitions = crate::parse(dmntk_examples::DMN_3_0006, "file://3_0006.dmn").unwrap();
   assert_eq!("_7a8aaf11-5415-4d91-92c0-f9f1a26ba81d", definitions.id().as_ref().unwrap().as_str());
 }
 
 #[test]
-fn test_3_0007() {
+fn _3_0007() {
   // <definitions>
   let definitions = crate::parse(dmntk_examples::DMN_3_0007, "file://3_0007.dmn").unwrap();
   assert_eq!("_69430b3e-17b8-430d-b760-c505bf6469f9", definitions.id().as_ref().unwrap().as_str());
 }
 
 #[test]
-fn test_3_0008() {
+fn _3_0008() {
   // <definitions>
   let definitions = crate::parse(dmntk_examples::DMN_3_0008, "file://3_0008.dmn").unwrap();
   assert_eq!("_ba93cb90-ea2e-4b18-8915-7a5493c52e34", definitions.id().as_ref().unwrap().as_str());
 }
 
 #[test]
-fn test_parse_context_3_0016() {
+fn _3_0014() {
+  // <definitions>
+  let definitions = crate::parse(dmntk_examples::DMN_3_0014, "file://3_0014.dmn").unwrap();
+  assert_eq!("_56c7d4a5-e6db-4bba-ac5f-dc082a16f719", definitions.id().as_ref().unwrap().as_str());
+}
+
+#[test]
+fn _3_0016() {
   let definitions = crate::parse(dmntk_examples::DMN_3_0016, "file:///3_0016.dmn").unwrap();
   assert_eq!("_51b7609d-c550-4660-b4c1-6ee5b4f1e8fe", definitions.id().as_ref().unwrap().as_str());
   // <definitions>.<decision>
@@ -393,42 +402,35 @@ fn test_parse_context_3_0016() {
 }
 
 #[test]
-fn test_3_0014() {
-  // <definitions>
-  let definitions = crate::parse(dmntk_examples::DMN_3_0014, "file://3_0014.dmn").unwrap();
-  assert_eq!("_56c7d4a5-e6db-4bba-ac5f-dc082a16f719", definitions.id().as_ref().unwrap().as_str());
-}
-
-#[test]
-fn test_3_0020() {
+fn _3_0020() {
   // <definitions>
   let definitions = crate::parse(dmntk_examples::DMN_3_0020, "file://3_0020.dmn").unwrap();
   assert_eq!("_819c015c-7ede-4404-876e-e96417aed322", definitions.id().as_ref().unwrap().as_str());
 }
 
 #[test]
-fn test_3_0030() {
+fn _3_0030() {
   // <definitions>
   let definitions = crate::parse(dmntk_examples::DMN_3_0030, "file://3_0030.dmn").unwrap();
   assert_eq!("_3cc4a1ee-68b8-4fc3-b686-e690f8fa7dcc", definitions.id().as_ref().unwrap().as_str());
 }
 
 #[test]
-fn test_3_0082() {
+fn _3_0082() {
   // <definitions>
   let definitions = crate::parse(dmntk_examples::DMN_3_0082, "file://3_0082.dmn").unwrap();
   assert_eq!("_6cd7f5d2-7cbb-45ea-b9bd-58ab1b6f678c", definitions.id().as_ref().unwrap().as_str());
 }
 
 #[test]
-fn test_3_0085() {
+fn _3_0085() {
   // <definitions>
   let definitions = crate::parse(dmntk_examples::DMN_3_0085, "file://3_0085.dmn").unwrap();
   assert_eq!("_56ed8ec7-c342-4abc-9278-27b46ca991c6", definitions.id().as_ref().unwrap().as_str());
 }
 
 #[test]
-fn test_3_0087() {
+fn _3_0087() {
   // <definitions>
   let definitions = crate::parse(dmntk_examples::DMN_3_0087, "file://3_0087.dmn").unwrap();
   assert_eq!("_9d01a0c4-f529-4ad8-ad8e-ec5fb5d96ad4", definitions.id().as_ref().unwrap().as_str());
@@ -436,11 +438,11 @@ fn test_3_0087() {
   let knowledge_source = definitions.knowledge_source_by_id("_989d137f-86ff-4249-813f-af67c08a2762").unwrap();
   assert_eq!("_989d137f-86ff-4249-813f-af67c08a2762", knowledge_source.id().as_ref().unwrap().as_str());
   assert_eq!("Credit officer", knowledge_source.name());
-  assert_eq!(r#"["Credit","officer"]"#, knowledge_source.feel_name().as_ref().unwrap().stringify());
+  assert_eq!(r#"Credit officer"#, knowledge_source.feel_name().as_ref().unwrap().to_string());
 }
 
 #[test]
-fn test_3_0088() {
+fn _3_0088() {
   // <definitions>
   let definitions = crate::parse(dmntk_examples::DMN_3_0088, "file://3_0088.dmn").unwrap();
   assert_eq!("_67ff55d6-2882-4432-89a9-354faba866be", definitions.id().as_ref().unwrap().as_str());
