@@ -16,8 +16,26 @@
 
 use crate::model::*;
 
+///
+fn get_shape(elements: &[DmnDiagramElement], index: usize) -> Option<&DmnShape> {
+  let element = elements.get(index).unwrap();
+  match element {
+    DmnDiagramElement::DmnShape(dmn_shape) => Some(dmn_shape),
+    _ => None,
+  }
+}
+
+///
+fn get_edge(elements: &[DmnDiagramElement], index: usize) -> Option<&DmnEdge> {
+  let element = elements.get(index).unwrap();
+  match element {
+    DmnDiagramElement::DmnEdge(dmn_edge) => Some(dmn_edge),
+    _ => None,
+  }
+}
+
 #[test]
-fn test_2_0001_dmndi() {
+fn _2_0001() {
   let definitions = crate::parse(dmntk_examples::DMN_2_0001, "file://2_0001.dmn").unwrap();
   assert_eq!("_c910c9ba-c584-4ac9-a773-1e6de185cd85", definitions.id().as_ref().unwrap().as_str());
   let dmndi = definitions.dmndi.unwrap();
@@ -50,7 +68,7 @@ fn test_2_0001_dmndi() {
   let shape_1 = get_shape(&dmndi.diagrams.get(0).unwrap().diagram_elements, 1).unwrap();
   assert_eq!("_48ea7a1d-2575-4cb7-8b63-8baa4cb3b371", shape_1.id.as_ref().unwrap());
   // there is a second shape's dmn_element_ref
-  assert_eq!("_84f6cc55-bb54-428e-bed0-2440d4c69e07", shape_1.dmn_element_ref.as_ref().unwrap());
+  assert_eq!("_cba86e4d-e91c-46a2-9176-e9adf88e15db", shape_1.dmn_element_ref.as_ref().unwrap());
   // there is a second shape's bound - height
   assert!(60.0_f64.eq(&shape_1.bounds.height));
   // there is a second shape's bound - width
@@ -74,24 +92,8 @@ fn test_2_0001_dmndi() {
   assert!(211.0_f64.eq(&edge_0.way_points.get(1).unwrap().y));
 }
 
-fn get_shape(elements: &[DmnDiagramElement], index: usize) -> Option<&DmnShape> {
-  let element = elements.get(index).unwrap();
-  match element {
-    DmnDiagramElement::DmnShape(dmn_shape) => Some(dmn_shape),
-    _ => None,
-  }
-}
-
-fn get_edge(elements: &[DmnDiagramElement], index: usize) -> Option<&DmnEdge> {
-  let element = elements.get(index).unwrap();
-  match element {
-    DmnDiagramElement::DmnEdge(dmn_edge) => Some(dmn_edge),
-    _ => None,
-  }
-}
-
 #[test]
-fn test_2_0002_dmndi() {
+fn _2_0002() {
   let definitions = crate::parse(dmntk_examples::DMN_2_0002, "file://2_0002.dmn").unwrap();
   assert_eq!("_072005e3-2635-47c9-8dec-5aca4b869376", definitions.id().as_ref().unwrap().as_str());
   let dmndi = definitions.dmndi.unwrap();
@@ -148,10 +150,8 @@ fn test_2_0002_dmndi() {
   assert!(211.0_f64.eq(&edge_0.way_points.get(1).unwrap().y));
 }
 
-// compliance-level-3/0086-import
-// sharedStyle and labels
 #[test]
-fn test_3_0086_dmndi() {
+fn _3_0086() {
   let definitions = crate::parse(dmntk_examples::DMN_3_0086, "file://3_0086.dmn").unwrap();
   assert_eq!("_f27bb64b-6fc7-4e1f-9848-11ba35e0df36", definitions.id().as_ref().unwrap().as_str());
   let dmndi = definitions.dmndi.unwrap();
@@ -291,10 +291,8 @@ fn test_3_0086_dmndi() {
   assert!(!style.font_strike_through);
 }
 
-// compliance-level-3/0087-chapter-11
-// DmnDecisionServiceDividerLine and isCollapsed
 #[test]
-fn test_3_0087_dmndi() {
+fn _3_0087() {
   let definitions = crate::parse(dmntk_examples::DMN_3_0087, "file://3_0087.dmn").unwrap();
   assert_eq!("_9d01a0c4-f529-4ad8-ad8e-ec5fb5d96ad4", definitions.id().as_ref().unwrap().as_str());
   let dmndi = definitions.dmndi.unwrap();
